@@ -1,6 +1,5 @@
 import datetime as dt
 import warnings
-from distutils.version import LooseVersion
 from functools import partial
 from numbers import Number
 from typing import Any, Callable, Dict, Hashable, Sequence, Union
@@ -12,7 +11,7 @@ from . import utils
 from .common import _contains_datetime_like_objects, ones_like
 from .computation import apply_ufunc
 from .duck_array_ops import datetime_to_numeric, push, timedelta_to_numeric
-from .options import _get_keep_attrs
+from .options import OPTIONS, _get_keep_attrs
 from .pycompat import dask_version, is_duck_dask_array
 from .utils import OrderedSet, is_scalar
 from .variable import Variable, broadcast_variables
@@ -405,6 +404,12 @@ def _bfill(arr, n=None, axis=-1):
 
 def ffill(arr, dim=None, limit=None):
     """forward fill missing values"""
+    if not OPTIONS["use_bottleneck"]:
+        raise RuntimeError(
+            "ffill requires bottleneck to be enabled."
+            " Call `xr.set_options(use_bottleneck=True)` to enable it."
+        )
+
     axis = arr.get_axis_num(dim)
 
     # work around for bottleneck 178
@@ -422,6 +427,12 @@ def ffill(arr, dim=None, limit=None):
 
 def bfill(arr, dim=None, limit=None):
     """backfill missing values"""
+    if not OPTIONS["use_bottleneck"]:
+        raise RuntimeError(
+            "bfill requires bottleneck to be enabled."
+            " Call `xr.set_options(use_bottleneck=True)` to enable it."
+        )
+
     axis = arr.get_axis_num(dim)
 
     # work around for bottleneck 178
@@ -545,16 +556,8 @@ def _localize(var, indexes_coords):
     """
     indexes = {}
     for dim, [x, new_x] in indexes_coords.items():
-        if np.issubdtype(new_x.dtype, np.datetime64) and LooseVersion(
-            np.__version__
-        ) < LooseVersion("1.18"):
-            # np.nanmin/max changed behaviour for datetime types in numpy 1.18,
-            # see https://github.com/pydata/xarray/pull/3924/files
-            minval = np.min(new_x.values)
-            maxval = np.max(new_x.values)
-        else:
-            minval = np.nanmin(new_x.values)
-            maxval = np.nanmax(new_x.values)
+        minval = np.nanmin(new_x.values)
+        maxval = np.nanmax(new_x.values)
         index = x.to_index()
         imin = index.get_loc(minval, method="nearest")
         imax = index.get_loc(maxval, method="nearest")
