@@ -12,6 +12,7 @@ from .utils import (
     _process_cmap_cbar_kwargs,
     get_axis,
     label_from_attrs,
+    plt,
 )
 
 # copied from seaborn
@@ -134,8 +135,7 @@ def _infer_scatter_data(ds, x, y, hue, markersize, size_norm, size_mapping=None)
 
 # copied from seaborn
 def _parse_size(data, norm):
-
-    import matplotlib as mpl
+    mpl = plt.matplotlib
 
     if data is None:
         return None
@@ -544,8 +544,6 @@ def quiver(ds, x, y, ax, u, v, **kwargs):
 
     Wraps :py:func:`matplotlib:matplotlib.pyplot.quiver`.
     """
-    import matplotlib as mpl
-
     if x is None or y is None or u is None or v is None:
         raise ValueError("Must specify x, y, u, v for quiver plots.")
 
@@ -560,7 +558,7 @@ def quiver(ds, x, y, ax, u, v, **kwargs):
 
         # TODO: Fix this by always returning a norm with vmin, vmax in cmap_params
         if not cmap_params["norm"]:
-            cmap_params["norm"] = mpl.colors.Normalize(
+            cmap_params["norm"] = plt.Normalize(
                 cmap_params.pop("vmin"), cmap_params.pop("vmax")
             )
 
@@ -576,8 +574,6 @@ def streamplot(ds, x, y, ax, u, v, **kwargs):
 
     Wraps :py:func:`matplotlib:matplotlib.pyplot.streamplot`.
     """
-    import matplotlib as mpl
-
     if x is None or y is None or u is None or v is None:
         raise ValueError("Must specify x, y, u, v for streamplot plots.")
 
@@ -613,7 +609,7 @@ def streamplot(ds, x, y, ax, u, v, **kwargs):
 
         # TODO: Fix this by always returning a norm with vmin, vmax in cmap_params
         if not cmap_params["norm"]:
-            cmap_params["norm"] = mpl.colors.Normalize(
+            cmap_params["norm"] = plt.Normalize(
                 cmap_params.pop("vmin"), cmap_params.pop("vmax")
             )
 
