@@ -9,8 +9,8 @@ from .utils import (
     _get_nice_quiver_magnitude,
     _infer_xy_labels,
     _process_cmap_cbar_kwargs,
-    import_matplotlib_pyplot,
     label_from_attrs,
+    plt,
 )
 
 # Overrides axes.labelsize, xtick.major.size, ytick.major.size
@@ -116,8 +116,6 @@ class FacetGrid:
 
         """
 
-        plt = import_matplotlib_pyplot()
-
         # Handle corner case of nonunique coordinates
         rep_col = col is not None and not data[col].to_index().is_unique
         rep_row = row is not None and not data[row].to_index().is_unique
@@ -175,11 +173,11 @@ class FacetGrid:
         )
 
         # Set up the lists of names for the row and column facet variables
-        col_names = list(data[col].values) if col else []
-        row_names = list(data[row].values) if row else []
+        col_names = list(data[col].to_numpy()) if col else []
+        row_names = list(data[row].to_numpy()) if row else []
 
         if single_group:
-            full = [{single_group: x} for x in data[single_group].values]
+            full = [{single_group: x} for x in data[single_group].to_numpy()]
             empty = [None for x in range(nrow * ncol - len(full))]
             name_dicts = full + empty
         else:
@@ -253,7 +251,7 @@ class FacetGrid:
             raise ValueError("cbar_ax not supported by FacetGrid.")
 
         cmap_params, cbar_kwargs = _process_cmap_cbar_kwargs(
-            func, self.data.values, **kwargs
+            func, self.data.to_numpy(), **kwargs
         )
 
         self._cmap_extend = cmap_params.get("extend")
@@ -349,7 +347,7 @@ class FacetGrid:
 
         if hue and meta_data["hue_style"] == "continuous":
             cmap_params, cbar_kwargs = _process_cmap_cbar_kwargs(
-                func, self.data[hue].values, **kwargs
+                func, self.data[hue].to_numpy(), **kwargs
             )
             kwargs["meta_data"]["cmap_params"] = cmap_params
             kwargs["meta_data"]["cbar_kwargs"] = cbar_kwargs
@@ -425,7 +423,7 @@ class FacetGrid:
     def add_legend(self, **kwargs):
         self.figlegend = self.fig.legend(
             handles=self._mappables[-1],
-            labels=list(self._hue_var.values),
+            labels=list(self._hue_var.to_numpy()),
             title=self._hue_label,
             loc="center right",
             **kwargs,
@@ -519,10 +517,8 @@ class FacetGrid:
         self: FacetGrid object
 
         """
-        import matplotlib as mpl
-
         if size is None:
-            size = mpl.rcParams["axes.labelsize"]
+            size = plt.rcParams["axes.labelsize"]
 
         nicetitle = functools.partial(_nicetitle, maxchar=maxchar, template=template)
 
@@ -619,13 +615,11 @@ class FacetGrid:
         self : FacetGrid object
 
         """
-        plt = import_matplotlib_pyplot()
-
         for ax, namedict in zip(self.axes.flat, self.name_dicts.flat):
             if namedict is not None:
                 data = self.data.loc[namedict]
                 plt.sca(ax)
-                innerargs = [data[a].values for a in args]
+                innerargs = [data[a].to_numpy() for a in args]
                 maybe_mappable = func(*innerargs, **kwargs)
                 # TODO: better way to verify that an artist is mappable?
                 # https://stackoverflow.com/questions/33023036/is-it-possible-to-detect-if-a-matplotlib-artist-is-a-mappable-suitable-for-use-w#33023522
